@@ -11,7 +11,7 @@ from celery import Celery
 from firexapp.celery_manager import CeleryManager
 from firexapp.submit.uid import Uid
 from firexapp.broker_manager.broker_factory import BrokerFactory, REDIS_BIN_ENV
-from firexkit.inspect import get_active
+from firexkit.inspect import get_active, get_revoked
 from firexapp.common import qualify_firex_bin, select_env_vars
 
 logger = logging.getLogger(__name__)
@@ -20,6 +20,7 @@ logger = logging.getLogger(__name__)
 CELERY_SHUTDOWN_WAIT = 5 * 60
 MaybeCeleryActiveTasks = namedtuple('MaybeCeleryActiveTasks', ['celery_read_success', 'active_tasks'])
 
+
 def launch_background_shutdown(logs_dir, reason):
     try:
         shutdown_cmd = [qualify_firex_bin("firex_shutdown"), "--logs_dir",  logs_dir]
@@ -56,7 +57,6 @@ def wait_for_broker_shutdown(broker, timeout=15, force_kill=True):
     return not broker.is_alive()
 
 
-
 def get_active_broker_safe(broker, celery_app):
     #
     # Note: get_active can hang in celery/kombu library if broker is down.
@@ -67,6 +67,12 @@ def get_active_broker_safe(broker, celery_app):
     return get_active(inspect_retry_timeout=4, celery_app=celery_app)
 
 
+def get_revoked_broker_safe(broker, celery_app):
+    if not broker.is_alive():
+        return None
+    return get_revoked(inspect_retry_timeout=4, celery_app=celery_app)
+
+
 def _tasks_from_active(active, task_predicate) -> MaybeCeleryActiveTasks:
     if active is None:
         return MaybeCeleryActiveTasks(False, None)
@@ -80,6 +86,7 @@ def revoke_active_tasks(broker, celery_app,  max_revoke_retries=5, task_predicat
     logger.debug("Querying Celery to find any remaining active tasks.")
     maybe_active_tasks = _tasks_from_active(get_active_broker_safe(broker, celery_app), task_predicate)
     revoke_retries = 0
+    # Revoke retry loop
     while (maybe_active_tasks.celery_read_success
            and maybe_active_tasks.active_tasks
            and revoke_retries < max_revoke_retries):
@@ -93,8 +100,14 @@ def revoke_active_tasks(broker, celery_app,  max_revoke_retries=5, task_predicat
             logger.info(f"Revoking {task['name']}[{task['id']}]")
             celery_app.control.revoke(task_id=task["id"], terminate=True)
 
-        time.sleep(3)
+        # wait for confirmation of revoke
         maybe_active_tasks = _tasks_from_active(get_active_broker_safe(broker, celery_app), task_predicate)
+        wait_for_task_revoke_start = time.monotonic()
+        while maybe_active_tasks.celery_read_success and maybe_active_tasks.active_tasks \
+                and time.monotonic() - wait_for_task_revoke_start < 3:
+            time.sleep(0.25)
+            maybe_active_tasks = _tasks_from_active(get_active_broker_safe(broker, celery_app), task_predicate)
+
         revoke_retries += 1
 
     if not maybe_active_tasks.celery_read_success:
